@@ -366,7 +366,7 @@ FIXME openbsd
 			paddr_t pa;
 
 			if (pmap_extract(pmap, a, &pa) == FALSE)
-				panic("iomap pmap error addr 0x%lx\n", a);
+				panic("iomap pmap error addr 0x%lx\n", (long unsigned int)a);
 #if 0
 FIXME openbsd			
 			err = iommu_iomap_insert_page(ims, pa);
@@ -463,7 +463,7 @@ FIXME openbsd
 
 			/* Yuck... Redoing the same pmap_extract... */
 			if (pmap_extract(pmap, a, &pa) == FALSE)
-				panic("iomap pmap error addr 0x%lx\n", a);
+				panic("iomap pmap error addr 0x%lx\n", (long unsigned int)a);
 
 			pgstart = pa | (MAX(a, addr) & PAGE_MASK);
 			pgend = pa | (MIN(a + PAGE_SIZE - 1,
@@ -959,7 +959,7 @@ FIXME openbsd
 	mutex_exit(&is->is_lock);
 #endif 
 	if (error != 0)
-		printf("warning: %ld of DVMA space lost\n", sgsize);
+		printf("warning: %ld of DVMA space lost\n", (long int)sgsize);
 }
 
 void
