@@ -400,14 +400,14 @@ vpci_conf_read(pci_chipset_tag_t pc, pcitag_t tag, int reg)
 		    hv_rc);
 	
 	pcireg_t val = error_flag ? (pcireg_t)~0 : data;
-	DPRINTF(VPCI_DB_CONF, ("vpci_conf_read() reg 0x%x  returning 0x%x\n", reg, val));
+	/*DPRINTF(VPCI_DB_CONF, ("vpci_conf_read() reg 0x%x  returning 0x%x\n", reg, val));*/
 	return val;
 }
 
 void
 vpci_conf_write(pci_chipset_tag_t pc, pcitag_t tag, int reg, pcireg_t data)
 {
-	DPRINTF(VPCI_DB_CONF, ("vpci_conf_write() reg 0x%x  data 0x%x\n", reg, data));
+	/*DPRINTF(VPCI_DB_CONF, ("vpci_conf_write() reg 0x%x  data 0x%x\n", reg, data));*/
 	struct vpci_pbm *pbm = pc->cookie;
 	uint64_t error_flag;
 
